#! /usr/bin/python

"""
Detect target distribution series

Detect which distribution series we're being built for so that we can emit
appropriately versioned dependencies.  This is tricky because our different
build environments express this in different ways.  Recipe builds for the
Launchpad PPA have a changelog header line that looks like this:

  launchpad-dependencies (0.97~lucid1) natty; urgency=low

While builds by the Canonical admin team look like this:

  launchpad-dependencies (0.97~0.IS.10.04) lucid-cat; urgency=low

Therefore, we test the version first, and then the target distribution.  If
we find neither, assume that we're building for the most current series we
support.
"""

import sys
import subprocess

targets = ('lucid', 'maverick', 'natty', 'oneiric')

def changelog_field(field):
    parser = subprocess.Popen(['dpkg-parsechangelog'], stdout=subprocess.PIPE)
    for line in parser.stdout:
        if line.lower().startswith('%s:' % field):
            return line.split(':', 1)[1].strip()
    return ''

def main():
    version = changelog_field('version')
    for target in targets:
        if target in version:
            print target
            return 0

    distroseries = changelog_field('distribution')
    for target in targets:
        if distroseries.startswith(target):
            print target
            return 0

    print targets[-1]
    return 0

if __name__ == '__main__':
    sys.exit(main())
